******
pydash
******

|version| |travis| |coveralls| |license|

A utility library for doing "stuff" in a functional way. Based on the `Lo-Dash <http://lodash.com/>`_  Javascript library.


Links
=====

- Project: https://github.com/dgilland/pydash
- Documentation: http://pydash.readthedocs.org
- PyPi: https://pypi.python.org/pypi/pydash/
- TravisCI: https://travis-ci.org/dgilland/pydash


.. |version| image:: http://img.shields.io/pypi/v/pydash.svg?style=flat
    :target: https://pypi.python.org/pypi/pydash/

.. |travis| image:: http://img.shields.io/travis/dgilland/pydash/master.svg?style=flat
    :target: https://travis-ci.org/dgilland/pydash

.. |coveralls| image:: http://img.shields.io/coveralls/dgilland/pydash/master.svg?style=flat
    :target: https://coveralls.io/r/dgilland/pydash

.. |license| image:: http://img.shields.io/pypi/l/pydash.svg?style=flat
    :target: https://pypi.python.org/pypi/pydash/
